<?php

namespace App\Http\Controllers\mla;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Caste;
use App\Models\User;
use App\Models\UserDetail;
use Auth;
use Str;

class CasteController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if($request->paginate){
            $paginate = $request->paginate;
        }else{
            $paginate = 10;
        }
        if($request->sort_f){
            $sort_f  = $request->sort_f ;
        }else{
            $sort_f  = 'id';
        }
        if($request->sort_by){
            $sort_by   = $request->sort_by  ;
        }else{
            $sort_by  = 'DESC';
        }
    
        $caste = Caste::orderBy($sort_f,$sort_by);
        $search = $request->search;
             if($search){
           $caste = $caste->where('caste_name','LIKE', '%'.$search.'%');
             }
             $caste = $caste->where('status',1)->paginate($paginate)->onEachSide(0);
       
        return view('mla.caste.index',compact('caste','paginate','search','sort_f','sort_by'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('mla.caste.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [

            'caste_name' => 'required',
           
            
        ]);
        $caste=new Caste;
        $caste->caste_name=Str::upper($request->caste_name);
        $caste->creator_id=Auth::user()->id;
        $caste->status='1';
        $caste->unique_id=uniqid();
        $caste->save();

         session()->flash('success_msg', 'New Caste has been created successfully');
         return redirect()->route('mcaste.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=Caste::where('unique_id',$id)->value('id');
        $row=Caste::find($id);
        return view('mla.caste.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            
         
            'caste_name' => 'required',
          
        ]);
        $caste=Caste::find($id);
        $caste->caste_name=Str::upper($request->caste_name);
        $caste->caste_id=Auth::user()->id;
        $caste->save();

         session()->flash('success_msg', 'Caste has been updated successfully');
         return redirect()->route('mcaste.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $caste_id=Caste::where('unique_id',$id)->value('id'); 
        $caste=Caste::find($caste_id);
        $caste->status="2";
        $caste->save();
        
        session()->flash('success_msg', 'Caste has been deleted successfully');
        return back();
    }
}
