<?php

namespace App\Http\Controllers\mla;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Category;
use App\Models\User;
use App\Models\UserDetail;
use Auth;
use Str;

class CategoryController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if($request->paginate){
            $paginate = $request->paginate;
        }else{
            $paginate = 10;
        }
        if($request->sort_f){
            $sort_f  = $request->sort_f ;
        }else{
            $sort_f  = 'id';
        }
        if($request->sort_by){
            $sort_by   = $request->sort_by  ;
        }else{
            $sort_by  = 'DESC';
        }
    
        $category = Category::orderBy($sort_f,$sort_by);
        $search = $request->search;
             if($search){
           $category = $category->where('category_name','LIKE', '%'.$search.'%');
             }
             $category = $category->where('status',1)->paginate($paginate)->onEachSide(0);
       
        return view('mla.category.index',compact('category','paginate','search','sort_f','sort_by'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('mla.category.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [

            'category_name' => 'required',
           
            
        ]);
        $category=new Category;
        $category->category_name=Str::upper($request->category_name);
        $category->creator_id=Auth::user()->id;
        $category->status='1';
        $category->unique_id=uniqid();
        $category->save();

         session()->flash('success_msg', 'New Category has been created successfully');
         return redirect()->route('mcategory.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=Category::where('unique_id',$id)->value('id');
        $row=Category::find($id);
        return view('mla.category.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            
         
            'category_name' => 'required',
          
        ]);
        $category=Category::find($id);
        $category->category_name=Str::upper($request->category_name);
        $category->creator_id=Auth::user()->id;
        $category->save();

         session()->flash('success_msg', 'Category has been updated successfully');
         return redirect()->route('mcategory.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $category_id=Category::where('unique_id',$id)->value('id'); 
        $category=Category::find($category_id);
        $category->status="2";
        $category->save();
        
        session()->flash('success_msg', 'Category has been deleted successfully');
        return back();
    }
}