<?php

namespace App\Http\Controllers\mla;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\VidhanSabha;
use App\Models\Category;
use App\Models\Inventory;
use App\Models\Requirement;
use App\Models\User;
use App\Models\UserDetail;
use Auth;
use Str;

class RequirementController extends Controller
{
   /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        if($request->paginate){
            $paginate = $request->paginate;
        }else{
            $paginate = 10;
        }
        if($request->sort_f){
            $sort_f  = $request->sort_f ;
        }else{
            $sort_f  = 'id';
        }
        if($request->sort_by){
            $sort_by   = $request->sort_by  ;
        }else{
            $sort_by  = 'DESC';
        }
       $user = User::where('create_by', Auth::user()->id)->pluck('id')->toArray();
        $requirement = Requirement::orderBy($sort_f,$sort_by)->whereIn('user_id',$user);
        $search = $request->search;
             if($search){
           $requirement = $requirement->where('category','LIKE', '%'.$search.'%')->orwhere('quantity','LIKE', '%'.$search.'%')->orwhere('date','LIKE', '%'.$search.'%')->orwhere('name','LIKE', '%'.$search.'%');
             }
             $requirement = $requirement->where('status',1)->paginate($paginate)->onEachSide(0);
        return view('mla.requirement.index',compact('requirement','paginate','search','sort_f','sort_by'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vidhansabha = VidhanSabha::where('status' ,'1')->pluck('vidhansabha', 'id')->toarray();
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();
        $user=User::whereHas('roles', function($q){
            $q->where('name','superadmin');
        })->where('status',1)->pluck('name','id')->toArray();
    
        return view('mla.requirement.create',compact('vidhansabha','category','user'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
          
            'category_name' => 'required',
         
            
        ]);

        $requirement = new Requirement;   
        $requirement->category_id=Str::upper($request->category_name);
        $requirement->quantity=$request->quantity;
        $requirement->action=$request->action;
        $requirement->date=$request->date;
        $requirement->remark=$request->remark;
        $requirement->status = 1;
        $requirement->unique_id=uniqid();
        $requirement->creator_id=Auth::user()->id;
        $requirement->save();  

        session()->flash('success_msg', 'New Requirement has been created successfully');
        return redirect()->route('mrequirement.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $category = Category::where('status' ,'1')->pluck('category_name', 'id')->toarray();
      
        $user=User::whereHas('roles', function($q){
            $q->where('name','superadmin');
        })->where('status',1)->pluck('name','id')->toArray();
        $id=Requirement::where('unique_id',$id)->value('id');
        $row=Requirement::find($id);
        return view('mla.requirement.edit',compact('row','category','user'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            
            'category_name' => 'required',
          
        ]);
        $requirement=Requirement::find($id);   
        $requirement->category_id=Str::upper($request->category_name);
        $requirement->quantity=$request->quantity;
        $requirement->action=$request->action;
        $requirement->date=$request->date;
        $requirement->remark=$request->remark;
        $requirement->save();

         session()->flash('success_msg', 'Requirement has been updated successfully');
         return redirect()->route('mrequirement.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $requirement_id=Requirement::where('unique_id',$id)->value('id'); 
        $requirement=Requirement::find($requirement_id);
        $requirement->status="2";
        $requirement->save();
        
        session()->flash('success_msg', 'Requirement has been deleted successfully');
        return back();
    }
}