<?php

namespace App\Http\Controllers\superadmin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\UserDetail;
use Auth;
use Str;

class MlaController extends Controller
{
    public function index(Request $request)
    {
        if($request->paginate){
            $paginate = $request->paginate;
        }else{
            $paginate = 10;
        }
        if($request->sort_f){
            $sort_f  = $request->sort_f ;
        }else{
            $sort_f  = 'id';
        }
        if($request->sort_by){
            $sort_by   = $request->sort_by  ;
        }else{
            $sort_by  = 'DESC';
        }

        $search = $request->search;
        $mla = User::where('status',1)->orderBy($sort_f,$sort_by)->whereHas('roles', function($q){
            $q->where('name', 'mla');
        });
        if($search){
            $mla = $mla->where('name','LIKE','%'.$search.'%')->whereHas('roles', function($q){
                $q->whereNotIn('name', ['superadmin','admin','booth','user']);
            });
        }
       $mla =  $mla->paginate($paginate)->onEachSide(0);
        return view('superadmin.mla.index',compact('mla','paginate','search','sort_f','sort_by'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        return view('superadmin.mla.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required|unique:users',
            'mobile_no' => 'required',
            'password' => 'required',


        ]);

        $user = new User;
        $user->name=Str::upper($request->name);
        $user->create_by = Auth::user()->id;
        $user->vidhansahba_id = $request->vidhansahba;
        $user->party_id = $request->party;
        $user->email = $request->email;
        $user->mobile_no = $request->mobile_no;
        $user->role = 'mla';
        $user->status = 1;
        $user->password = bcrypt($request->password);
        $user->assignRole('mla');
        $user->unique_id=uniqid();
        $user->save();

        session()->flash('success', 'New MLA has been created successfully');
        return redirect()->route('samla.index');
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=User::where('unique_id',$id)->value('id');
        $row=User::find($id);
        return view('superadmin.mla.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'email' => 'required',
            'mobile_no' => 'required',

        ]);

        $user =User::find($id);
        $user->name = $request->name;
        $user->email = $request->email;
        $user->mobile_no=$request->mobile_no;
        $user->vidhansahba_id = $request->vidhansahba;
        $user->party_id = $request->party;
        $user->save();

        session()->flash('success','MLA has been updated successfully');
        return redirect()->route('samla.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user_id=User::where('unique_id',$id)->value('id');
        $user=User::find($user_id);
        $user->status="2";
        $user->save();

        session()->flash('success_msg', 'MLA has been deleted successfully');
        return back();
    }
}
